@@ -141,7 +141,7 @@ def SearchFetchable(session=None, **kwargs):
     :type session: :class:`~okcupyd.session.Session`
     :param location: A location string which will be used to filter results.
     :param gender: The gender of the user performing the search.
-    :param keywords: A list or space string of words to search for.
+    :param keywords: A list or space delimeted string of words to search for.
     :param order_by: The criteria to use for ordering results. expected_values:
                      'match', 'online', 'special_blend'
     """
