@@ -2,6 +2,7 @@ import datetime
 import logging
 import itertools
 import os
+import time
 
 import mock
 import contextlib2 as contextlib
@@ -66,7 +67,7 @@ patch_settings = patch('credentials_modules',
 patch_save = patch('resave',
                    mock.patch.object(
                        Cassette, '_save',
-                       okcupyd_util.n_partialable(Cassette._save)(force=True)))
+                       okcupyd_util.curry(Cassette._save)(force=True)))
 patch_use_cassette_enabled = patch('skip_vcrpy',
                                    mock.patch.object(CassetteContextDecorator,
                                                      '__enter__'),
@@ -258,3 +259,11 @@ def pytest_exception_interact():
         log.info(model_class_to_instances)
     except:
         pass
+
+
+@pytest.fixture
+def vcr_live_sleep(request):
+    return (time.sleep
+            if (request.config.getoption('record') or
+                request.config.getoption('skip_vcrpy'))
+            else mock.Mock())
