@@ -142,12 +142,6 @@ def test_language_filter():
     assert 'afrikaans' in map(operator.itemgetter(0), profile.details.languages)
 
 
-@util.use_cassette
-def test_join_date_filter():
-    session = Session.login()
-    SearchFetchable(session, join_date='week', count=1)[0]
-
-
 @util.use_cassette
 def test_attractiveness_filter():
     session = Session.login()
